@@ -33,7 +33,8 @@ typedef enum
 {
   EPHY_DOWNLOAD_ACTION_NONE,
   EPHY_DOWNLOAD_ACTION_BROWSE_TO,
-  EPHY_DOWNLOAD_ACTION_OPEN
+  EPHY_DOWNLOAD_ACTION_OPEN,
+  EPHY_DOWNLOAD_ACTION_DO_NOT_AUTO_OPEN
 } EphyDownloadActionType;
 
 EphyDownload *ephy_download_new                   (WebKitDownload *download);
@@ -58,7 +59,8 @@ guint32       ephy_download_get_start_time        (EphyDownload *download);
 EphyDownloadActionType ephy_download_get_action   (EphyDownload *download);
 void          ephy_download_set_action            (EphyDownload *download,
                                                    EphyDownloadActionType action);
-gboolean      ephy_download_do_download_action    (EphyDownload *download,
-                                                   EphyDownloadActionType action);
+gboolean      ephy_download_do_download_action    (EphyDownload          *download,
+                                                   EphyDownloadActionType action,
+                                                   guint32                user_time);
 
 G_END_DECLS
